@@ -2,7 +2,7 @@
 """
 :Author: CaiYouBin
 :Date: 2020-05-12 20:04:54
-@LastEditTime: 2022-02-17 09:23:51
+@LastEditTime: 2022-02-24 15:22:47
 @LastEditors: HuangJianYi
 :description: 基础接口
 """
@@ -242,7 +242,6 @@ class ActHandler(SevenBaseHandler):
         :param index_desc: 首页配置
         :param shakebox_tips: 摇盒提示配置
         :param shakebox_tips_num: 摇盒次数
-        :param task_currency_type: 任务货币类型
         :return: 
         :last_editors: HuangJingCan
         """
@@ -261,7 +260,6 @@ class ActHandler(SevenBaseHandler):
         shakebox_tips = self.get_param("shakebox_tips")
         shakebox_tips_num = self.get_param("shakebox_tips_num", 0)
         exceed_tips = self.get_param("exceed_tips")
-        task_currency_type = self.get_param("task_currency_type")
 
         act_info_model = ActInfoModel(context=self)
         if act_id > 0:
@@ -282,7 +280,6 @@ class ActHandler(SevenBaseHandler):
             act_info.exceed_tips = exceed_tips
             act_info.is_black = is_black
             act_info.is_task = is_task
-            act_info.task_currency_type = task_currency_type
             act_info.refund_count = refund_count
             act_info.store_url = store_url
             act_info.modify_date = self.get_now_datetime()
@@ -316,6 +313,7 @@ class ActSaveHandler(SevenBaseHandler):
         :param shakebox_tips: 摇盒提示配置
         :param shakebox_tips_num: 摇盒次数
         :param exceed_tips: 超出次数提示内容
+        :param task_currency_type: 任务货币类型
         :return: 
         :last_editors: HuangJingCan
         """
@@ -327,6 +325,7 @@ class ActSaveHandler(SevenBaseHandler):
         rule_desc = self.get_param("rule_desc", "")
         is_black = self.get_param("is_black", "")
         is_task = self.get_param("is_task", "")
+        task_currency_type = self.get_param("task_currency_type", "")
         theme_id = self.get_param("theme_id")
         refund_count = self.get_param("refund_count", "")
         store_url = self.get_param("store_url", "")
@@ -353,6 +352,8 @@ class ActSaveHandler(SevenBaseHandler):
                 act_info.rule_desc = self.json_dumps(rule_desc) if rule_desc != "" else []
             if index_desc:
                 act_info.index_desc = self.json_dumps(index_desc) if index_desc != "" else {}
+            if task_currency_type:
+                act_info.task_currency_type = task_currency_type
             if shakebox_tips:
                 act_info.shakebox_tips = self.json_dumps(shakebox_tips) if shakebox_tips != "" else []
             if shakebox_tips_num:
@@ -410,6 +411,7 @@ class ActListHandler(SevenBaseHandler):
             page_list, total = ActInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)
 
             for page in page_list:
+                page["task_currency_type"] = self.json_loads(page["task_currency_type"]) if page["task_currency_type"] else {}
                 page["share_desc"] = self.json_loads(page["share_desc"]) if page["share_desc"] else {}
                 page["rule_desc"] = self.json_loads(page["rule_desc"]) if page["rule_desc"] else []
                 page["index_desc"] = self.json_loads(page["index_desc"]) if page["index_desc"] else {}
@@ -443,6 +445,7 @@ class ActInfoHandler(SevenBaseHandler):
         act_info = ActInfoModel(context=self).get_entity_by_id(act_id)
 
         if act_info:
+            act_info.task_currency_type = self.json_loads(act_info.task_currency_type) if act_info.task_currency_type else {}
             act_info.share_desc = self.json_loads(act_info.share_desc)
             act_info.rule_desc = self.json_loads(act_info.rule_desc)
             act_info.index_desc = self.json_loads(act_info.index_desc)
