@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2021-04-14 15:51:04
-@LastEditTime: 2021-09-01 14:38:55
+@LastEditTime: 2022-02-17 16:45:24
 @LastEditors: HuangJianYi
 :Description: 用户权限相关
 """
@@ -42,5 +42,6 @@ class ShopPowerConfigHandler(SevenBaseHandler):
         if not user_nick:
             return self.reponse_json_error("Error", "对不起,请先授权登录")
         store_user_nick = user_nick.split(':')[0]
-        power_base_model = PowerBaseModel()
-        self.reponse_json_success(power_base_model.get_config_data(store_user_nick, self.get_taobao_param().access_token))
\ No newline at end of file
+        power_base_model = PowerBaseModel(context=self)
+        app_key, app_secret = self.get_app_key_secret()
+        self.reponse_json_success(power_base_model.get_config_data(store_user_nick, self.get_taobao_param().access_token, app_key, app_secret))
